@@ -4,12 +4,13 @@ import decimal
 from collections import namedtuple
 from dataclasses import asdict
 from datetime import date
+from decimal import Decimal
 from enum import Enum
 from typing import Optional, Any, Union, Sequence, List, Tuple
 
-import pytz
+import zoneinfo
 from django.utils.html import escape
-from pydantic import validate_arguments
+from pydantic import validate_call
 from pydantic.dataclasses import dataclass as pydantic_dataclass
 from qr_code.qrcode.constants import DEFAULT_MODULE_SIZE, SIZE_DICT, DEFAULT_ERROR_CORRECTION, DEFAULT_IMAGE_FORMAT
 
@@ -21,10 +22,10 @@ class QRCodeOptions:
     Represents the options used to create and draw a QR code.
     """
 
-    @validate_arguments
+    @validate_call
     def __init__(
         self,
-        size: Union[int, str, None] = DEFAULT_MODULE_SIZE,
+        size: Union[int, float, str, Decimal, None] = DEFAULT_MODULE_SIZE,
         border: int = 4,
         version: Union[int, str, None] = None,
         image_format: str = "svg",
@@ -33,8 +34,8 @@ class QRCodeOptions:
         boost_error: bool = True,
         micro: bool = False,
         eci: bool = False,
-        dark_color: Union[tuple, str, bool, None] = "#000",
-        light_color: Union[tuple, str, bool, None] = "#fff",
+        dark_color: Union[tuple, str, bool, None] = "black",
+        light_color: Union[tuple, str, bool, None] = "white",
         finder_dark_color: Union[tuple, str, bool, None] = False,
         finder_light_color: Union[tuple, str, bool, None] = False,
         data_dark_color: Union[tuple, str, bool, None] = False,
@@ -52,48 +53,45 @@ class QRCodeOptions:
         quiet_zone_color: Union[tuple, str, bool, None] = False,
     ) -> None:
         """
-        :param size: The size of the QR code as an integer or a string. Default is *'m'*.
-        :type: str or int
+        :param size: The size of the QR code as an integer, float, Decimal or a string. Default is *'m'*.
+        :type: str, int, float or Decimal
         :param int border: The size of the border (blank space around the code).
-        :param version: The version of the QR code gives the size of the matrix.
-            Default is *None* which mean automatic in order to avoid data overflow.
-        :param version: QR Code version. If the value is ``None`` (default), the
-            minimal version which fits for the input data will be used.
-            Valid values: "M1", "M2", "M3", "M4" (for Micro QR codes) or an
-            integer between 1 and 40 (for QR codes).
-            The `version` parameter is case insensitive.
+        :param version: The version of the QR code gives the size of the matrix. Default is *None* which mean automatic
+            in order to avoid data overflow.
+
+        :param version: QR Code version. If the value is ``None`` (default), the minimal version which fits for the
+            input data will be used. Valid values: "M1", "M2", "M3", "M4" (for Micro QR codes) or an integer between
+            1 and 40 (for QR codes). The `version` parameter is case insensitive.
+
         :type version: int, str or None
-        :param str image_format: The graphics format used to render the QR code.
-            It can be either *'svg'* or *'png'*. Default is *'svg'*.
-        :param str error_correction: How much error correction that might be required
-            to read the code. It can be either *'L'*, *'M'*, *'Q'*, or *'H'*. Default is *'M'*.
+        :param str image_format: The graphics format used to render the QR code. It can be either *'svg'* or *'png'*. Default is *'svg'*.
+        :param str error_correction: How much error correction that might be required to read the code. It can be
+            either *'L'*, *'M'*, *'Q'*, or *'H'*. Default is *'M'*.
+
         :param bool boost_error: Tells whether the QR code encoding engine tries to increase the error correction level
-            if it does not affect the version. Error correction level is not increased when it impacts the version of
-            the code.
+            if it does not affect the version. Error correction level is not increased when it impacts the version of the code.
+
         :param bool micro: Indicates if a Micro QR Code should be created. Default: False
-        :param encoding: Indicates the encoding in mode "byte". By default
-            `encoding` is ``UTF-8``. When set to ``None``, the implementation tries to use the standard conform
-            ISO/IEC 8859-1 encoding and if it does not fit, it will use UTF-8. Note that no ECI mode indicator is
-            inserted by default (see :paramref:`eci`).
-            The `encoding` parameter is case-insensitive.
+        :param encoding: Indicates the encoding in mode "byte". By default `encoding` is ``UTF-8``. When set to
+            ``None``, the implementation tries to use the standard conform ISO/IEC 8859-1 encoding and if it does not
+            fit, it will use UTF-8. Note that no ECI mode indicator is inserted by default (see ``eci``). The `encoding`
+            parameter is case-insensitive.
+
         :type encoding: str or None
-        :param bool eci: Indicates if binary data which does not use the default
-            encoding (ISO/IEC 8859-1) should enforce the ECI mode. Since a lot
-            of QR code readers do not support the ECI mode, this feature is
-            disabled by default and the data is encoded in the provided
-            `encoding` using the usual "byte" mode. Set `eci` to ``True`` if
-            an ECI header should be inserted into the QR Code. Note that
-            the implementation may not know the ECI designator for the provided
-            `encoding` and may raise an exception if the ECI designator cannot
-            be found.
-            The ECI mode is not supported by Micro QR Codes.
-        :param dark_color: Color of the dark modules (default: black). The
-            color can be provided as ``(R, G, B)`` tuple, as hexadecimal
-            format (``#RGB``, ``#RRGGBB`` ``RRGGBBAA``), or web color
-            name (i.e. ``red``). If alpha transparency is supported (i.e. PNG and SVG), hexadecimal values like #RRGGBBAA are accepted.
-        :param light_color: Color of the light modules (default: white).
-            See `color` for valid values. If light is set to ``None`` the
-            light modules will be transparent.
+        :param bool eci: Indicates if binary data which does not use the default encoding (ISO/IEC 8859-1) should
+            enforce the ECI mode. Since a lot of QR code readers do not support the ECI mode, this feature is disabled
+            by default and the data is encoded in the provided `encoding` using the usual "byte" mode. Set ``eci`` to
+            ``True`` if an ECI header should be inserted into the QR Code. Note that the implementation may not know
+            the ECI designator for the provided `encoding` and may raise an exception if the ECI designator cannot be
+            found. The ECI mode is not supported by Micro QR Codes.
+
+        :param dark_color: Color of the dark modules (default: black). The color can be provided as ``(R, G, B)`` tuple,
+            as hexadecimal format (``#RGB``, ``#RRGGBB`` ``RRGGBBAA``), or web color name (i.e. ``red``). If alpha
+            transparency is supported (i.e. PNG and SVG), hexadecimal values like #RRGGBBAA are accepted.
+
+        :param light_color: Color of the light modules (default: transparent). See `color` for valid values. If light
+            is set to ``None`` the light modules will be transparent.
+
         :param finder_dark_color: Color of the dark finder modules (default: same as ``dark_color``)
         :param finder_light_color: Color of the light finder modules (default: same as ``light_color``)
         :param data_dark_color: Color of the dark data modules (default: same as ``dark_color``)
@@ -110,12 +108,13 @@ class QRCodeOptions:
         :param dark_module_color: Color of the dark module (default: same as ``dark_color``)
         :param quiet_zone_color: Color of the quiet zone modules (default: same as ``light_color``)
 
-        The *size* parameter gives the size of each module of the QR code matrix. It can be either a positive integer or one of the following letters:
-            * t or T: tiny (value: 6)
-            * s or S: small (value: 12)
-            * m or M: medium (value: 18)
-            * l or L: large (value: 30)
-            * h or H: huge (value: 48)
+        The *size* parameter gives the size of each module of the QR code matrix. It can be either a positive integer
+        or one of the following letters:
+        * t or T: tiny (value: 6)
+        * s or S: small (value: 12)
+        * m or M: medium (value: 18)
+        * l or L: large (value: 30)
+        * h or H: huge (value: 48)
 
         For PNG image format the size unit is in pixels, while the unit is 0.1 mm for SVG format.
 
@@ -131,10 +130,10 @@ class QRCodeOptions:
         There are 4 error correction levels used for QR codes, with each one adding different amounts of "backup" data
         depending on how much damage the QR code is expected to suffer in its intended environment, and hence how much
         error correction may be required. The correction level can be configured with the *error_correction* parameter as follow:
-            * l or L: error correction level L – up to 7% damage
-            * m or M: error correction level M – up to 15% damage
-            * q or Q: error correction level Q – up to 25% damage
-            * h or H: error correction level H – up to 30% damage
+        * l or L: error correction level L – up to 7% damage
+        * m or M: error correction level M – up to 15% damage
+        * q or Q: error correction level Q – up to 25% damage
+        * h or H: error correction level H – up to 30% damage
 
         You may enforce the creation of a Micro QR Code with `micro=True`. The `micro` option defaults to `False`.
 
@@ -219,7 +218,7 @@ class QRCodeOptions:
         :rtype: dict
         """
         image_format = self._image_format
-        kw = dict(border=self.border, kind=image_format, scale=self._size_as_int())
+        kw = dict(border=self.border, kind=image_format, scale=self._size_as_number())
         # Change the color mapping into the keywords Segno expects
         # (remove the "_color" suffix from the module names)
         kw.update({k[:-6]: v for k, v in self.color_mapping().items()})
@@ -234,26 +233,25 @@ class QRCodeOptions:
 
         Only non-default values are returned.
 
-        :rtype: dict
+        :rtype: d
         """
         colors = {k: v for k, v in self._colors.items() if v is not False}
-        # Remove common default "dark" and "light" values
-        if colors.get("dark_color") in ("#000", "#000000", "black"):
-            del colors["dark_color"]
-        if colors.get("light_color") in ("#fff", "#FFF", "#ffffff", "#FFFFFF", "white"):
-            del colors["light_color"]
         return colors
 
-    def _size_as_int(self):
+    def _size_as_number(self) -> Union[int, float, str, Decimal]:
         """Returns the size as integer value.
 
-        :rtype: int
+        :rtype: int or float
         """
         size = self._size
         if _can_be_cast_to_int(size):
-            actual_size = int(size)
+            actual_size = int(size)  # type: ignore
             if actual_size < 1:
                 actual_size = SIZE_DICT[DEFAULT_MODULE_SIZE]
+        elif isinstance(size, (float, Decimal)):
+            actual_size = size  # type: ignore
+            if actual_size < Decimal("0.01"):
+                actual_size = SIZE_DICT[DEFAULT_MODULE_SIZE]
         elif isinstance(size, str):
             actual_size = SIZE_DICT.get(size.lower(), DEFAULT_MODULE_SIZE)
         else:
@@ -414,14 +412,14 @@ class VEvent:
             if is_naive_datetime(t):
                 return t.strftime("%Y%m%dT%H%M%S")
             else:
-                t_utc = t.astimezone(pytz.utc)
+                t_utc = t.astimezone(zoneinfo.ZoneInfo("UTC"))
                 return t_utc.strftime("%Y%m%dT%H%M%SZ")
 
         event_str = f"""BEGIN:VCALENDAR
 PRODID:Django QR Code
 VERSION:2.0
 BEGIN:VEVENT
-DTSTAMP:{(self.dtstamp or datetime.datetime.utcnow()).astimezone(pytz.utc).strftime("%Y%m%dT%H%M%SZ")}
+DTSTAMP:{(self.dtstamp or datetime.datetime.utcnow()).astimezone(zoneinfo.ZoneInfo('UTC')).strftime("%Y%m%dT%H%M%SZ")}
 UID:{self.uid}
 DTSTART:{get_datetime_str(self.start)}
 DTEND:{get_datetime_str(self.end)}
@@ -520,7 +518,7 @@ class ContactDetail:
         * org: organization or company name (non-standard,but often recognized, ORG field).
     """
 
-    @validate_arguments
+    @validate_call
     def __init__(
         self,
         first_name: Optional[str] = None,
@@ -670,8 +668,7 @@ class VCard:
     is supported.
 
     Fields meaning:
-    name: The name. If it contains a semicolon, , the first part
-            is treated as lastname and the second part is treated as forename.
+    name: The name. If it contains a semicolon, the first part is treated as lastname and the second part is treated as forename.
     displayname: Common name.
     email: E-mail address. Multiple values are allowed.
     phone: Phone number. Multiple values are allowed.
@@ -679,8 +676,7 @@ class VCard:
     videophone: Phone number for video calls. Multiple values are allowed.
     memo: A notice for the contact.
     nickname: Nickname.
-    birthday: Birthday. If a string is provided, it should encode the
-                     date as ``YYYY-MM-DD`` value.
+    birthday: Birthday. If a string is provided, it should encode the date as ``YYYY-MM-DD`` value.
     url: Homepage. Multiple values are allowed.
     pobox: P.O. box (address information).
     street: Street address.
@@ -748,7 +744,7 @@ class VCard:
 @pydantic_dataclass
 class WifiConfig:
     """\
-    Represents a WIFI configuration.
+    Represents a WI-FI configuration.
 
     Fields meaning:
         * ssid: the name of the SSID
@@ -760,17 +756,16 @@ class WifiConfig:
     AUTHENTICATION = namedtuple("AUTHENTICATION", "nopass WEP WPA")._make(range(3))  # type: ignore
     AUTHENTICATION_CHOICES = ((AUTHENTICATION.nopass, "nopass"), (AUTHENTICATION.WEP, "WEP"), (AUTHENTICATION.WPA, "WPA"))
 
-    def __init__(self, ssid: str = "", authentication: int = AUTHENTICATION.nopass, password: str = "", hidden: bool = False) -> None:
-        self.ssid = ssid
-        self.authentication = authentication
-        self.password = password
-        self.hidden = hidden
+    ssid: str = ""
+    authentication: int = AUTHENTICATION.nopass
+    password: str = ""
+    hidden: bool = False
 
     def make_qr_code_data(self) -> str:
         """
         Make a text for configuring a Wi-Fi connexion. The syntax is inspired by the MeCARD format used for contacts.
 
-        :return: the WIFI configuration text that can be translated to a QR code.
+        :return: the WI-FI configuration text that can be translated to a QR code.
         :rtype: str
         """
 
@@ -794,8 +789,8 @@ class Coordinates:
 
     Fields meaning:
         * latitude: The latitude.
-        * latitude: The longitude.
-        * latitude: The optional altitude.
+        * longitude: The longitude.
+        * altitude: The optional altitude.
     """
 
     latitude: float
@@ -867,7 +862,7 @@ class Email:
         return helpers.make_make_email_data(**asdict(self))
 
 
-@validate_arguments
+@validate_call
 def _escape_mecard_special_chars(string_to_escape: Optional[str]) -> Optional[str]:
     if not string_to_escape:
         return string_to_escape
