@@ -4,6 +4,6 @@ from qr_code_demo import views
 
 app_name = "qr_code_demo"
 urlpatterns = [
-    path('', views.index, name='index'),
-    path('qr-code/', include('qr_code.urls', namespace="qr_code")),
+    path("", views.index, name="index"),
+    path("qr-code/", include("qr_code.urls", namespace="qr_code")),
 ]
